summaryrefslogtreecommitdiff
path: root/src/mesa/main/dd.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mesa/main/dd.h')
-rw-r--r--src/mesa/main/dd.h22
1 files changed, 6 insertions, 16 deletions
diff --git a/src/mesa/main/dd.h b/src/mesa/main/dd.h
index e69ad2d740..d88e9d3055 100644
--- a/src/mesa/main/dd.h
+++ b/src/mesa/main/dd.h
@@ -1,4 +1,4 @@
-/* $Id: dd.h,v 1.61 2001/04/04 21:54:20 brianp Exp $ */
+/* $Id: dd.h,v 1.62 2001/06/15 14:18:46 brianp Exp $ */
/*
* Mesa 3-D graphics library
@@ -346,16 +346,12 @@ struct dd_function_table {
* should do the job.
*/
- GLboolean (*IsCompressedFormat)(GLcontext *ctx, GLint internalFormat);
- /* Called to tell if a format is a compressed format.
- */
-
void (*GetCompressedTexImage)( GLcontext *ctx, GLenum target,
- GLint lod, void *image,
+ GLint level, void *image,
const struct gl_texture_object *texObj,
struct gl_texture_image *texImage );
/* Called by glGetCompressedTexImageARB.
* <target>, <lod>, <image> are specified by user.
* <texObj> is the source texture object.
* <texImage> is the source texture image.
*/
@@ -368,6 +364,9 @@ struct dd_function_table {
* Example: if internalFormat==GL_COMPRESSED_RGB_FXT1_3DFX, return GL_RGB.
*/
+ GLint (*CompressedTextureSize)(GLcontext *ctx,
+ const struct gl_texture_image *texImage);
+
#if 000
/* ... Note the
* return value differences between this function and
@@ -394,15 +393,6 @@ struct dd_function_table {
* do the right thing with it.
*/
- GLsizei (*CompressedImageSize)(GLcontext *ctx,
- GLenum internalFormat,
- GLuint numDimensions,
- GLuint width,
- GLuint height,
- GLuint depth);
- /* Calculate the size of a compressed image, given the image's
- * format and dimensions.
- */
#endif
/***
@@ -346,16 +346,12 @@ struct dd_function_table {
struct gl_texture_image *texImage );
/* Called by glGetCompressedTexImageARB.
- * <target>, <lod>, <image> are specified by user.
+ * <target>, <level>, <image> are specified by user.
* <texObj> is the source texture object.
* <texImage> is the source texture image.